@@ -17,6 +17,8 @@ module Web.Twitter.Conduit.Parameters
        , HasExcludeRepliesParam (..)
        , HasContributorDetailsParam (..)
        , HasIncludeEntitiesParam (..)
+       , HasIncludeEmailParam (..)
+       , HasIncludeExtAltTextParam (..)
        , HasIncludeUserEntitiesParam (..)
        , HasIncludeRtsParam (..)
        , HasIncludeMyRetweetParam (..)
@@ -74,9 +76,11 @@ defineHasParamClassBool "trim_user"
 defineHasParamClassBool "exclude_replies"
 defineHasParamClassBool "contributor_details"
 defineHasParamClassBool "include_entities"
+defineHasParamClassBool "include_email"
 defineHasParamClassBool "include_user_entities"
 defineHasParamClassBool "include_rts"
 defineHasParamClassBool "include_my_retweet"
+defineHasParamClassBool "include_ext_alt_text"
 defineHasParamClassInteger "in_reply_to_status_id"
 defineHasParamClassBool "display_coordinates"
 defineHasParamClassBool "possibly_sensitive"
